DecompressionContext

Struct DecompressionContext 

pub struct DecompressionContext {
    decompressor: Decompressor<'static>,
}
Additional context that may be needed for decompression.

In the case of zstd, this will contain the zstd decompression context, which can be reused between subsequent decompression calls to avoid the performance overhead of initialising a new context for every decompression.

Fields

decompressor: Decompressor<'static>

Implementations

Source

impl DecompressionContext

pub(crate) fn new() -> Self