pub struct IpcWriteContext {
pub(crate) scratch: Vec<u8>,
fbb: FlatBufferBuilder<'static>,
compressor: Option<Compressor<'static>>,
}Expand description
Additional context that may be needed for compression.
In the case of zstd, this will contain the zstd context, which can be reused between subsequent
compression calls to avoid the performance overhead of initialising a new context for every
compression. Also holds a [FlatBufferBuilder] that is reused across IPC writes.
Fields
scratch: Vec<u8>fbb: FlatBufferBuilder<'static>compressor: Option<Compressor<'static>>Implementations
Sourceimpl IpcWriteContext
impl IpcWriteContext
Sourcepub(crate) fn mut_fbb(&mut self) -> &mut FlatBufferBuilder<'static>
pub(crate) fn mut_fbb(&mut self) -> &mut FlatBufferBuilder<'static>
Get a mutable reference to the [FlatBufferBuilder] that is reused across IPC writes.
fn zstd_compressor(&mut self, level: i32) -> &mut Compressor<'static>