fn read_uncompressed_size(buffer: &[u8]) -> Result<i64, ArrowError>Expand description
Get the uncompressed length Notes: LENGTH_NO_COMPRESSED_DATA: indicate that the data that follows is not compressed 0: indicate that there is no data positive number: indicate the uncompressed length for the following data Returns an error if the input buffer is shorter than 8 bytes