pub fn try_fb_to_schema(fb: Schema<'_>) -> Result<Schema, ArrowError>Expand description
Deserialize an ipc crate::Schema from flat buffers to an arrow [Schema].
Returns an error on schema messages that the flatbuffer verifier accepts but that are not valid Arrow.