pub struct IpcWriteContext { /* private fields */ }Expand description
Additional context that may be needed for compression.
In the case of zstd, this will contain the zstd context, which can be reused between subsequent
compression calls to avoid the performance overhead of initialising a new context for every
compression. Also holds a FlatBufferBuilder that is reused across IPC writes.