IpcMessageSinkExt

Trait IpcMessageSinkExt 

trait IpcMessageSinkExt: IpcMessageSink {
    // Provided methods
    fn write_padding(&mut self, len: usize) -> Result<(), ArrowError> { ... }
    fn write_continuation(
        &mut self,
        write_options: &IpcWriteOptions,
        metadata_len: i32,
    ) -> Result<(), ArrowError> { ... }
    fn write_body_data(
        &mut self,
        data: Vec<u8>,
        alignment: u8,
    ) -> Result<usize, ArrowError> { ... }
    fn write_encoded_data(
        &mut self,
        encoded: EncodedData,
        write_options: &IpcWriteOptions,
    ) -> Result<(usize, usize), ArrowError> { ... }
    fn write_eos(
        &mut self,
        write_options: &IpcWriteOptions,
    ) -> Result<(), ArrowError> { ... }
}
Shared IPC framing helpers for IpcMessageSink.

Provided Methods

fn write_padding(&mut self, len: usize) -> Result<(), ArrowError>

fn write_continuation( &mut self, write_options: &IpcWriteOptions, metadata_len: i32, ) -> Result<(), ArrowError>

Writes the IPC continuation marker and metadata length prefix.

fn write_body_data( &mut self, data: Vec<u8>, alignment: u8, ) -> Result<usize, ArrowError>

fn write_encoded_data( &mut self, encoded: EncodedData, write_options: &IpcWriteOptions, ) -> Result<(usize, usize), ArrowError>

Writes an already encoded IPC message with optional contiguous body data.

This is used for schema and dictionary messages represented by EncodedData. Returns the padded metadata length and body length written.

fn write_eos( &mut self, write_options: &IpcWriteOptions, ) -> Result<(), ArrowError>

Writes the IPC end-of-stream marker.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors