trait IpcRecordBatchSink: IpcMessageSinkExt {
// Provided method
fn write_record_batch(
&mut self,
metadata: Vec<u8>,
encoded_buffers: Vec<EncodedBuffer>,
body_len: usize,
tail_pad: usize,
write_options: &IpcWriteOptions,
) -> Result<(usize, usize), ArrowError> { ... }
}Expand description
Optional hot-path hook for record batch messages.
Provided Methods
Sourcefn write_record_batch(
&mut self,
metadata: Vec<u8>,
encoded_buffers: Vec<EncodedBuffer>,
body_len: usize,
tail_pad: usize,
write_options: &IpcWriteOptions,
) -> Result<(usize, usize), ArrowError>
fn write_record_batch( &mut self, metadata: Vec<u8>, encoded_buffers: Vec<EncodedBuffer>, body_len: usize, tail_pad: usize, write_options: &IpcWriteOptions, ) -> Result<(usize, usize), ArrowError>
Writes a record batch message from its encoded metadata and body buffers.
The body buffers are already materialized as EncodedBuffer segments,
allowing buffer output to preserve uncompressed Arrow buffers.
Returns the padded metadata length and body length written.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".